# ChatAI (beta)
ChatAI is a Python package for creating chatbot apps with easy integration of NLP and ML capabilities, allowing it to understand and respond to user input in an intelligent and natural way.

---------------------------
# chatai.x()

### Costum hello

* You need to provide "hello" to show to api the words

       hello = ["hi","hello"] 
      
       costumhello(hello)

### Casual Hello
* Dont worry about the words! We wrote you for you

        casualhello()

### Formal Hello
* Dont worry about the words! We wrote you for you

        formalhello()

### Costum How Are You
* You need to provide "hru" to show to api the words

      hru = ["How are you?","How’s it   going?"]

      costumhru(hru)

### Casual How Are You
* Dont worry about the words! We wrote you for you

        casualhru()

### Formal How Are You
* Dont worry about the words! We wrote you for you

        formalhru()

### Friends How Are You
* Dont worry about the words! We wrote you for you

        friendhru()

----------------------------

# What is ChatAI?
ChatAI is a Python package for creating chatbot applications. It allows developers to easily integrate natural language processing and machine learning capabilities into their chatbot, enabling it to understand and respond to user input in a more intelligent and natural way. With ChatBot, creating a custom chatbot for your business or website has never been easier. Give it a try!
